=======
History
=======

Initial Development (2016-12-14)
--------------------------------

* Parse incoming strings from the command prompt including data
* Only plotted data

Overhaul (2017-10-17)
---------------------

* Made into a package
* Made into a nice CLI
* Expanded data acquisition
* Plots and saves data

0.1.0 (2019-01-18)
------------------

* First release on PyPI.
* Opensourced!

0.2.0 (2019-01-19)
------------------

* Full daq system
* Complete API
* Documentation
* Complete access to the Lyte probe
